"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAsync = void 0;
var _react = require("react");
/**
 * Async wrapper for async/await functions with Promise return
 * @param asyncFn should return promise
 * @returns data - expected value of "asyncFn", error - something went wrong (unexpected), loading - is asyncFn running
 */
const useAsync = asyncFn => {
  const [data, setData] = (0, _react.useState)(null);
  const [error, setError] = (0, _react.useState)(null);
  const [isLoading, setIsLoading] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    const fetchData = async () => {
      setIsLoading(true);
      try {
        const result = await asyncFn();
        setData(result);
      } catch (err) {
        setError(err);
      } finally {
        setIsLoading(false);
      }
    };
    fetchData();
  }, [asyncFn]);
  return {
    data,
    error,
    loading: isLoading
  };
};
exports.useAsync = useAsync;
//# sourceMappingURL=useAsync.js.map